@@ -12,47 +12,30 @@
 #' @param MAP logical, if TRUE (default) the search targets the MAP DAG (a DAG with maximum score),
 #' if FALSE at each MCMC step a DAG is sampled from the order proportionally to its score
 #' @param plus1 logical, if TRUE (default) the search is performed on the extended search space
-#' @param moveprobs (optional) a numerical vector of 4 values in \code{\{0,1\}} corresponding to the probabilities of the following MCMC moves in the order space
+#' @param chainout logical, if TRUE the saved MCMC steps are returned, TRUE by default
+#' @param scoreout logical, if TRUE the search space and score tables are returned, FALSE by default
+#' @param moveprobs a numerical vector of 4 values in \code{\{0,1\}} corresponding to the probabilities of the following MCMC moves in the order space
 #' \itemize{
 #' \item exchanging 2 random nodes in the order
 #' \item exchanging 2 adjacent nodes in the order
 #' \item placing a single node elsewhere in the order
 #' \item staying still
 #' }
-#' @param iterations (optional) integer, the number of MCMC steps, the default value is \eqn{5n^{2}\log{n}}
-#' @param stepsave (optional) integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations/1000}
-#' @param alpha (optional) numerical significance value in \code{\{0,1\}} for the conditional independence tests at the PC algorithm stage (by default \eqn{0.4} for \eqn{n<50}, \eqn{20/n} for \eqn{n>50})
-#' @param gamma (optional) tuning parameter which transforms the score by raising it to this power, 1 by default
+#' @param iterations integer, the number of MCMC steps, the default value is \eqn{5n^{2}\log{n}}
+#' @param stepsave integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations/1000}
+#' @param alpha numerical significance value in \code{\{0,1\}} for the conditional independence tests at the PC algorithm stage (by default \eqn{0.4} for \eqn{n<50}, \eqn{20/n} for \eqn{n>50})
+#' @param gamma tuning parameter which transforms the score by raising it to this power, 1 by default
+#' @param cpdag logical, if TRUE the CPDAG returned by the PC algorithm will be used as the search
+#'space, if FALSE (default) the full undirected skeleton will be used as the search space
+#' @param hardlimit integer, limit on the size of parent sets in the search space; by default 14 when MAP=TRUE and 20 when MAP=FALSE
+#' @param verbose logical, if TRUE messages about the algorithm's progress will be printed, FALSE by default
 #' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix. If NULL, the skeleton obtained from the PC-algorithm will be used. If \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space. To include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1.
 #' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space. If \code{blacklist[i,j]} equals to 1 it means that the edge from node \code{i} to node \code{j} is excluded from the search space.
-#' @param scoretable (optional) list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}, to avoid their recomputation  The score tables must match the permissible parents in the search space defined by the startspace parameter.
-#' @param startorder (optional) integer vector of length n, which will be used as the starting order in the MCMC algorithm, the default order is \code{c(1:n)}
-#' @param cpdag (optional) logical, if TRUE the CPDAG returned by the PC algorithm will be used as the search
-#'space, if FALSE (default) the full undirected skeleton will be used as the search space
-#' @param hardlimit (optional) integer, limit on the size of parent sets in the search space
-#' @param chainout logical, if TRUE the saved MCMC steps are returned, TRUE by default
-#' @param scoreout logical, if TRUE the search space and score tables are returned, FALSE by default
-#' @param verbose logical, if TRUE messages about the algorithm's progress will be printed, FALSE by default
-#' @return Depends on the logical parameters \code{chainout} and \code{scoreout}.
-#'  If both are FALSE (default), an object of class \code{MCMCmax}, containing a list of 3 elements:
-#' \itemize{
-#' \item {DAG -} {the adjacency matrix of the DAG with maximal score}
-#' \item {order -} {an order it belongs to}
-#' \item {score -} {the score of the reported DAG}
-#' }
-#' If \code{chainout} is TRUE an object of class \code{MCMCtrace} is additionally returned, contains 4 lists  (each of the 4 lists has length
-#' \code{iterations/stepsave}, i.e. the number of saved MCMC steps):
-#' \itemize{
-#' \item incidence - contains a list of adjacency matrices of DAGs sampled at each step of MCMC
-#' \item DAGscores - contains a list of scores of DAGs sampled at each step of MCMC
-#' \item orderscores - contains a list of scores of orders of DAGs sampled at each step of MCMC
-#' \item order - contains a list of permutations of the nodes of DAGs sampled at each step of MCMC
-#' }
-#' If \code{scoreout} is TRUE an object of class \code{MCMCspace} is additionally returned, contains a list of 2 elements:
-#' \itemize{
-#'  \item adjacency - the adjacency matrix representing the search space
-#'  \item scoretable - the list of score tables corresponding to this search space
-#' }
+#' @param scoretable (optional) object of class \code{MCMCspace} containing list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}. When not NULL, parameter \code{startspace} is ignored.
+#' @param startorder (optional) integer vector of length n, which will be used as the starting order in the MCMC algorithm, the default order is random
+#' @return Object of class \code{MCMCres}, which contains log-score trace of sampled DAGs as well 
+#' as adjacency matrix of the maximum scoring DAG, its score and the order score. See \code{\link{MCMCres}}.
+#' The output can optionally include DAGs sampled in MCMC iterations and the score tables. Optional output is regulated by the parameters \code{chainout} and \code{scoreout}.
 #'@references Friedman N and Koller D (2003). A Bayesian approach to structure discovery in bayesian networks. Machine Learning 50, 95-125.
 #'@references Kalisch M, Maechler M, Colombo D, Maathuis M and Buehlmann P (2012). Causal inference using graphical models with the R package pcalg. Journal of Statistical Software 47, 1-26.
 #'@references Geiger D and Heckerman D (2002). Parameter priors for directed acyclic graphical models and the characterization of several probability distributions. The Annals of Statistics 30, 1412-1440.
@@ -61,7 +44,7 @@
 #'@examples
 #'\dontrun{
 #'#find a MAP DAG with search space defined by PC and plus1 neighbourhood
-#'Bostonscore<-scoreparameters(14,"bge",Boston)
+#'Bostonscore<-scoreparameters("bge",Boston)
 #'#estimate MAP DAG
 #'orderMAPfit<-orderMCMC(Bostonscore)
 #'summary(orderMAPfit)
@@ -69,14 +52,13 @@
 #'ordersamplefit<-orderMCMC(Bostonscore,MAP=FALSE,chainout=TRUE)
 #'plot(ordersamplefit)
 #'}
-#'
+#'@author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
 #'@export
 
-orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
-                    startspace=NULL, blacklist=NULL,startorder=NULL, scoretable=NULL,  
-                    moveprobs=NULL, iterations=NULL, stepsave=NULL, alpha=0.05, cpdag=FALSE, gamma=1,
-                    hardlimit=ifelse(plus1,15,22),
-                    chainout=TRUE, scoreout=FALSE, verbose=FALSE) {
+orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,chainout=FALSE, scoreout=FALSE, moveprobs=NULL, 
+                    iterations=NULL, stepsave=NULL, alpha=0.05, cpdag=FALSE, gamma=1,
+                    hardlimit=ifelse(plus1,14,20),verbose=FALSE,
+                    startspace=NULL, blacklist=NULL,startorder=NULL, scoretable=NULL) {
   if (is.null(moveprobs)) { 
     prob1<-99
     if(scorepar$nsmall>3){ prob1<-round(6*99*scorepar$nsmall/(scorepar$nsmall^2+10*scorepar$nsmall-24)) }
@@ -114,16 +96,13 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
     if(!is.null(startspace)) {
       startspace<-DBNbacktransform(startspace,scorepar)
     } 
-    
-   # if(!is.null(addspace)) {
-  #    addspace<-DBNbacktransform(addspace,scorepar)
-  #  }
+
   
     
     if(scorepar$split) { #we learn initial and transition structures separately
       
       if(scoreout | !is.null(scoretable)) {
-        print("option scoreout always equals FALSE for DBNs with samestruct=FALSE, scoretable parameter is ignored")
+        cat("option scoreout always equals FALSE for DBNs with samestruct=FALSE, scoretable parameter is ignored \n")
       }    
       result.init<-orderMCMCmain(param=scorepar$firstslice,iterations,stepsave,startorder=startorder$init,
                                moveprobs=moveprobs,alpha=alpha,cpdag=cpdag,scoretable=NULL,
@@ -138,7 +117,6 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
                                 hardlimit=hardlimit)
     
       result<-mergeDBNres(result.init,result.trans,scorepar,algo="order")
-    
     } else {
       
       result<-orderMCMCmain(param=scorepar,iterations,stepsave,startorder=startorder,
@@ -174,7 +152,7 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
     result$info$spacealgo<-"user defined matrix"
   }
   result$info$iterations<-iterations
-  result$info$samplesteps<-ceiling(iterations/stepsave)
+  result$info$samplesteps<-length(result$trace)
   if(MAP) {
     result$info$sampletype<-"MAP"
   } else {
@@ -193,10 +171,6 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
 #'The search space can be defined either by a preliminary run of the function \code{iterativeMCMC} or by a given adjacency matrix (which can be the full matrix with zero on the diagonal, to consider the entire space of DAGs, feasible only for a limited number of nodes). 
 #'
 #' @param scorepar an object of class \code{scoreparameters}, containing the data and scoring parameters;  see constructor function \code{\link{scoreparameters}}.
-#' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix; if NULL, the skeleton obtained from the PC-algorithm will be used. If \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space. To include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1.
-#' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space; if \code{blacklist[i,j]=1} it means that the edge from node \code{i} to node \code{j} is excluded from the search space
-#' @param scoretable (optional) list of score tables; for example calculated at the last iteration of the function \code{iterativeMCMC}, to avoid their recomputation; the score tables must match the permissible parents in the search space defined by the startspace parameter
-#' @param startDAG (optional) an adjacency matrix of dimensions equal to the number of nodes, representing a DAG in the search space defined by startspace.  If startspace is defined but \code{startDAG} is not, an empty DAG will be used by default
 #' @param moveprobs (optional) a numerical vector of 5 values in \code{\{0,1\}} corresponding to the following MCMC move probabilities in the space of partitions:
 #' \itemize{
 #' \item swap any two elements from different partition elements
@@ -205,19 +179,17 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
 #' \item move a single node into another partition element or into a new one
 #' \item stay still
 #' }
-#' @param iterations (optional) integer, the number of MCMC steps, the default value is \eqn{8n^{2}\log{n}}
-#' @param stepsave (optional) integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations/1000}
-#' @param gamma (optional) tuning parameter which transforms the score by raising it to this power, 1 by default
+#' @param iterations integer, the number of MCMC steps, the default value is \eqn{8n^{2}\log{n}}
+#' @param stepsave integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations/1000}
+#' @param gamma tuning parameter which transforms the score by raising it to this power, 1 by default
 #' @param verbose logical, if set to TRUE (default) messages about progress will be printed
-#' @return an object of class \code{MCMCtrace}, which contains a list of 5 elements (each list contains \code{iterations/stepsave} elements):
-#' \itemize{
-#' \item incidence - contains a list of adjacency matrices of DAGs sampled at each step of MCMC
-#' \item DAGscores - contains a list of scores of DAGs sampled at each step of MCMC
-#' \item partitionscores - contains a list of scores of partitions of DAGs sampled at each step of MCMC
-#' \item order - contains a list of permutations of the nodes in partitions of DAGs sampled at each step of MCMC
-#' \item partition - contains a list of partitions of DAGs sampled at each step of MCMC
-#' }
-#'
+#' @param scoreout logical, if TRUE the search space and score tables are returned, FALSE by default
+#' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix; if NULL, the skeleton obtained from the PC-algorithm will be used. If \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space. To include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1.
+#' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space; if \code{blacklist[i,j]=1} it means that the edge from node \code{i} to node \code{j} is excluded from the search space
+#' @param scoretable (optional) object of class \code{MCMCspace} containing list of score tables calculated for example by the last iteration of the function \code{iterativeMCMC}. When not NULL, parameter \code{startspace} is ignored
+#' @param startDAG (optional) an adjacency matrix of dimensions equal to the number of nodes, representing a DAG in the search space defined by startspace.  If startspace is defined but \code{startDAG} is not, an empty DAG will be used by default
+#' @return Object of class \code{MCMCres}, which contains log-score trace as well 
+#' as adjacency matrix of the maximum scoring DAG, its score and the order score. See \code{\link{MCMCres}}.
 #'@references Kuipers J and Moffa G (2017). Partition MCMC for inference on acyclic digraphs. Journal of the American Statistical Association 112, 282-299.
 #'@references Geiger D and Heckerman D (2002). Parameter priors for directed acyclic graphical models and the characterization of several probability distributions. The Annals of Statistics 30, 1412-1440.
 #'@references Heckerman D and Geiger D (1995). Learning Bayesian networks: A unification for discrete and Gaussian domains. In Eleventh Conference on Uncertainty in Artificial Intelligence, pages 274-284.
@@ -225,14 +197,15 @@ orderMCMC<-function(scorepar, MAP=TRUE, plus1=TRUE,
 #'@references Kuipers J, Moffa G and Heckerman D (2014). Addendum on the scoring of Gaussian directed acyclic graphical models. The Annals of Statistics 42, 1689-1691.
 #'@examples
 #'\dontrun{
-#'myScore<-scoreparameters(14, "bge", Boston)
+#'myScore<-scoreparameters("bge", Boston)
 #'partfit<-partitionMCMC(myScore)
 #'plot(partfit)
 #'}
 #'@import pcalg
+#'@author Polina Suter, Jack Kuipers, the code partly derived from the partition MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
 #'@export
-partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NULL, startDAG=NULL, 
-                        moveprobs=NULL, iterations=NULL,  stepsave=NULL,gamma=1,verbose=TRUE) {
+partitionMCMC<-function(scorepar, moveprobs=NULL, iterations=NULL,  stepsave=NULL,gamma=1,verbose=TRUE,
+                        scoreout=FALSE,startspace=NULL, blacklist=NULL,scoretable=NULL, startDAG=NULL) {
   if (is.null(moveprobs)) {
     prob1start<-40/100
     prob1<-prob1start*100
@@ -284,10 +257,10 @@ partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NUL
     if(scorepar$split) { #we learn initial and transition structures separately
       
       if(!is.null(scoretable)) {
-        print("for DBNs with samestruct=FALSE 'scoretable' parameter is ignored")
+        warning("for DBNs with samestruct=FALSE 'scoretable' parameter is ignored")
       }  
         
-      result.init<-partitionMCMCplus1sample(param=scorepar$firstslices,startspace=startspace$init,
+      result.init<-partitionMCMCplus1sample(param=scorepar$firstslice,startspace=startspace$init,
                                             blacklist=blacklist$init,moveprobs=moveprobs,
                                             numit=iterations,DAG=startDAG$init,stepsave=stepsave,
                                             scoretable=NULL,
@@ -330,8 +303,9 @@ partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NUL
     result$info$spacealgo<-"user defined matrix"
   }
   result$info$iterations<-iterations
-  result$info$samplesteps<-ceiling(iterations/stepsave)
+  result$info$samplesteps<-length(result$trace)
   result$info$sampletype<-"sample"
+  attr(result,"class")<-"MCMCres"
   return(result)
 }
 
@@ -349,35 +323,35 @@ partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NUL
 #'The final search space may be used for the sampling versions of \code{\link{orderMCMC}} and \code{\link{partitionMCMC}}.
 #'
 #' @param scorepar an object of class \code{scoreparameters}, containing the data and scoring parameters; see constructor function \code{\link{scoreparameters}}
-#' @param plus1it (optional) integer, a number of iterations of search space expansion; by default the algorithm iterates until no score improvement can be achieved by further expanding the search space
-#' @param moveprobs (optional) a numerical vector of 4 values in \code{\{0,1\}} corresponding to the probabilities of the following MCMC moves in the order space:
+#' @param moveprobs a numerical vector of 4 values in \code{\{0,1\}} corresponding to the probabilities of the following MCMC moves in the order space:
 #' \itemize{
 #' \item exchanging 2 random nodes in the order
 #' \item exchanging 2 adjacent nodes in the order
 #' \item placing a single node elsewhere in the order
 #' \item staying still
 #' }
-#' @param iterations (optional) integer, the number of MCMC steps, the default value is \eqn{3.5n^{2}\log{n}}
-#' @param stepsave (optional) integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations}/1000
+#' @param iterations integer, the number of MCMC steps, the default value is \eqn{3.5n^{2}\log{n}}
+#' @param stepsave integer, thinning interval for the MCMC chain, indicating the number of steps between two output iterations, the default is \code{iterations}/1000
 #' @param MAP logical, if TRUE (default) the search targets the MAP DAG (a DAG with maximum score),
 #' if FALSE at each MCMC step a DAG is sampled from the order proportionally to its score; when expanding a search space when MAP=TRUE all edges from the maximum scoring DAG are added
 #'  to the new space, when MAP=FALSE only edges with posterior probability higher than defined by parameter \code{posterior} are added to the search space
 #' @param posterior logical, when \code{MAP} set to FALSE defines posterior probability threshold for adding the edges to the search space 
-#' @param alpha (optional) numerical significance value in \code{\{0,1\}} for the conditional independence tests in the PC-stage (by default \eqn{0.4} for \eqn{n<50}, \eqn{20/n} for \eqn{n>50})
-#' @param gamma (optional) tuning parameter which transforms the score by raising it to this power, 1 by default
-#' @param startorder (optional) integer vector of length n, which will be used as the starting order in the MCMC algorithm, the default order is \code{c(1:n)}
-#' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix; if NULL, the skeleton obtained from the PC-algorithm will be used; if \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space; to include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1
-#' @param scoretable (optional) list of score tables which has to match startspace and addspace
-#' @param addspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the edges, which are added at to the search space only at the first iteration of iterative seach and do not necessarily stay afterwards; defined in the form of an adjacency matrix;  if \code{addspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space; to include an edge in both directions, both \code{addspace[i,j]} and \code{addspace[j,i]} should be 1
-#' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space; if \code{blacklist[i,j]} equals to 1 it means that the edge from node \code{i} to node \code{j} is excluded from the search space
-#' @param softlimit (optional) integer, limit on the size of parent sets beyond which adding undirected edges is restricted; below this
+#' @param alpha numerical significance value in \code{\{0,1\}} for the conditional independence tests in the PC-stage (by default \eqn{0.4} for \eqn{n<50}, \eqn{20/n} for \eqn{n>50})
+#' @param gamma tuning parameter which transforms the score by raising it to this power, 1 by default
+#' @param startorder integer vector of length n, which will be used as the starting order in the MCMC algorithm, the default order is random
+#' @param softlimit integer, limit on the size of parent sets beyond which adding undirected edges is restricted; below this
 #' limit edges are added to expand the parent sets based on the undirected skeleton of the MAP DAG (or from its CPDAG, depending
 #' on the parameter \code{mergecp}), above the limit only the directed edges are added from the MAP DAG;  the limit is 9 by default
-#' @param hardlimit (optional) integer, limit on the size of parent sets beyond which the search space is not further expanded to prevent long runtimes; the limit is 12 by default
+#' @param hardlimit integer, limit on the size of parent sets beyond which the search space is not further expanded to prevent long runtimes; the limit is 12 by default
 #' @param cpdag logical, if set to TRUE the equivalence class (CPDAG) found by the PC algorithm is used as a search
 #'  space, when FALSE (default) the undirected skeleton used as a search space
-#' @param mergetype defines which edges are added to the search space at each expansion iteration; if set to 
+#' @param mergetype defines which edges are added to the search space at each expansion iteration; three options are available 'dag', 'cpdag', 'skeleton'; 'skeleton' by default
 #' @param accum logical, when TRUE at each search step expansion new edges are added to the current search space; when FALSE (default) the new edges are added to the starting space
+#' @param plus1it (optional) integer, a number of iterations of search space expansion; by default the algorithm iterates until no score improvement can be achieved by further expanding the search space
+#' @param startspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the search space for the order MCMC in the form of an adjacency matrix; if NULL, the skeleton obtained from the PC-algorithm will be used; if \code{startspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space; to include an edge in both directions, both \code{startspace[i,j]} and \code{startspace[j,i]} should be 1
+#' @param scoretable (optional) object of class \code{MCMCscoretab} (see \code{\link{MCMCscoretab}}). When not NULL, parameters \code{startspace} and \code{addspace} are ignored.
+#' @param addspace (optional) a square matrix, of dimensions equal to the number of nodes, which defines the edges, which are added at to the search space only at the first iteration of iterative seach and do not necessarily stay afterwards; defined in the form of an adjacency matrix;  if \code{addspace[i,j]} equals to 1 (0) it means that the edge from node \code{i} to node \code{j} is included (excluded) from the search space; to include an edge in both directions, both \code{addspace[i,j]} and \code{addspace[j,i]} should be 1
+#' @param blacklist (optional) a square matrix, of dimensions equal to the number of nodes, which defines edges to exclude from the search space; if \code{blacklist[i,j]} equals to 1 it means that the edge from node \code{i} to node \code{j} is excluded from the search space
 #' \itemize{
 #' \item "dag", then edges from maximum scoring DAG are added;
 #' \item "cpdag", then the maximum scoring DAG is first converted to the CPDAG, from which all edges are added to the search space;
@@ -386,26 +360,9 @@ partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NUL
 #' @param verbose logical, if TRUE (default) prints messages on the progress of execution
 #' @param chainout logical, if TRUE the saved MCMC steps are returned, FALSE by default
 #' @param scoreout logical, if TRUE the search space from the last plus1 iterations and the corresponding score tables are returned, FALSE by default
-#' @return Depends on the logical parameters \code{chainout} and \code{scoreout}. If both are FALSE (default), an oject of class \code{MCMCmax}, containing a list of 4 elements:
-#' \itemize{
-#' \item {DAG -} {the adjacency matrix of the DAG with maximal score}
-#' \item {order -} {an order it belongs to}
-#' \item {score -} {the score of the reported DAG}
-#' \item {it -} {the iteration at which maximum was reached}
-#' }
-#' If \code{chainout} is TRUE an object of class \code{MCMCtrace} is additionally returned, contains 4 lists  (each of the 4 lists has length
-#' \code{iterations/stepsave}, i.e. the number of saved MCMC steps):
-#' \itemize{
-#' \item incidence - contains a list of adjacency matrices of DAGs sampled at each step of MCMC
-#' \item DAGscores - contains a list of scores of DAGs sampled at each step of MCMC
-#' \item orderscores - contains a list of scores of orders of DAGs sampled at each step of MCMC
-#' \item order - contains a list of permutations of the nodes of DAGs sampled at each step of MCMC
-#' }
-#' If \code{scoreout} is TRUE an object of class \code{MCMCspace} is additionally returned, contains a list of 2 elements:
-#' \itemize{
-#'  \item adjacency - the adjacency matrix representing the search space
-#'  \item scoretable - the list of score tables corresponding to this search space
-#' }
+#' @return Object of class \code{MCMCmult}, which contains log-score trace as well 
+#' as adjacency matrix of the maximum scoring DAG, its score and the order score. See \code{\link{MCMCmult}}.
+#' The output can optionally include DAGs sampled in MCMC iterations and the score tables. Optional output is regulated by the parameters \code{chainout} and \code{scoreout}.
 #'@references Friedman N and Koller D (2003). A Bayesian approach to structure discovery in bayesian networks. Machine Learning 50, 95-125.
 #'@references Kalisch M, Maechler M, Colombo D, Maathuis M and Buehlmann P (2012). Causal inference using graphical models with the R package pcalg. Journal of Statistical Software 47, 1-26.
 #'@references Geiger D and Heckerman D (2002). Parameter priors for directed acyclic graphical models and the characterization of several probability distributions. The Annals of Statistics 30, 1412-1440.
@@ -413,7 +370,7 @@ partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NUL
 #'@references Spirtes P, Glymour C and Scheines R (2000). Causation, Prediction, and Search, 2nd edition. The MIT Press.
 #'@examples
 #'\dontrun{
-#'Bostonpar<-scoreparameters(14,"bge",Boston)
+#'Bostonpar<-scoreparameters("bge",Boston)
 #'itfit<-iterativeMCMC(Bostonpar, chainout=TRUE, scoreout=TRUE)
 #'plot(itfit)
 #'}
@@ -440,17 +397,14 @@ partitionMCMC<-function(scorepar, startspace=NULL, blacklist=NULL,scoretable=NUL
 #'@importFrom graph plot
 #'@importFrom graph numNodes
 #'@importFrom Rcpp evalCpp
+#'@importFrom graphics abline
+#'@importFrom utils head
 #'@useDynLib BiDAG, .registration=TRUE
-# pcalg pc
-# pcalg skeleton
-# pcalg shd
-# pcalg dag2cpdag
 #'@export
-iterativeMCMC<-function(scorepar, plus1it=NULL, moveprobs=NULL, MAP=TRUE, posterior=0.5,
-                              iterations=NULL, stepsave=NULL, softlimit=9, hardlimit=12, alpha=0.05, gamma=1, 
-                              startspace=NULL, blacklist=NULL,verbose=TRUE, chainout=FALSE, scoreout=FALSE, cpdag=FALSE, 
-                              mergetype="skeleton",addspace=NULL,scoretable=NULL,startorder=NULL,
-                              accum=FALSE) {
+#'@author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
+iterativeMCMC<-function(scorepar, MAP=TRUE, posterior=0.5, softlimit=9, hardlimit=12, alpha=0.05, gamma=1, verbose=TRUE, chainout=FALSE, scoreout=FALSE, cpdag=FALSE, 
+                        mergetype="skeleton", iterations=NULL, moveprobs=NULL, stepsave=NULL,startorder=NULL,
+                        accum=FALSE, plus1it=NULL, startspace=NULL, blacklist=NULL,addspace=NULL,scoretable=NULL) {
   
   if (is.null(moveprobs)) {
     prob1<-99
@@ -499,18 +453,17 @@ iterativeMCMC<-function(scorepar, plus1it=NULL, moveprobs=NULL, MAP=TRUE, poster
     if(scorepar$split) { #we learn initial and transition structures separately
       
       if(scoreout | !is.null(scoretable)) {
-        print("option scoreout always equals FALSE for DBNs with samestruct=FALSE, scoretable parameter is ignored")
+        cat("option scoreout always equals FALSE for DBNs with samestruct=FALSE, scoretable parameter is ignored \n")
       }
       
-      #print(startorder$init)
-      #print(startorder$trans)
-      print("learning initial structure...")
+
+      cat("learning initial structure...\n")
       result.init<-iterativeMCMCplus1(param=scorepar$firstslice,iterations,stepsave,plus1it=plus1it, MAP=MAP, posterior=posterior,alpha=alpha,cpdag=cpdag,
                                       moveprobs=moveprobs,softlimit=softlimit,hardlimit=hardlimit,
                                       startspace=startspace$init,blacklist=blacklist$init,gamma=gamma,
                                       verbose=verbose, chainout=chainout,scoreout=FALSE,mergecp=mergetype,
                                       addspace=addspace$init,scoretable=NULL,startorder=startorder$init,accum=accum)
-      print("learning transition structure...")
+      cat("learning transition structure...\n")
       result.trans<-iterativeMCMCplus1(param=scorepar$otherslices,iterations,stepsave,plus1it=plus1it, MAP=MAP, posterior=posterior,alpha=alpha,cpdag=cpdag,
                                        moveprobs=moveprobs,softlimit=softlimit,hardlimit=hardlimit,
                                        startspace=startspace$trans,blacklist=blacklist$trans,gamma=gamma,
@@ -581,10 +534,11 @@ iterativeMCMC<-function(scorepar, plus1it=NULL, moveprobs=NULL, MAP=TRUE, poster
 #' @references Heckerman D and Geiger D (1995). Learning Bayesian networks: A unification for discrete and Gaussian domains. In Eleventh Conference on Uncertainty in Artificial Intelligence, pages 274-284.
 #' @references Kuipers J, Moffa G and Heckerman D (2014). Addendum on the scoring of Gaussian directed acyclic graphical models. The Annals of Statistics 42, 1689-1691.
 #' @examples
-#' myScore<-scoreparameters(8, "bde", Asia)
+#' myScore<-scoreparameters("bde", Asia)
 #' DAGscore(myScore, Asiamat)
 #' @import pcalg
 #' @export
+#' @author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
 DAGscore <- function(scorepar, incidence){ 
   if(scorepar$DBN) {
     stop("To calculate DBN score DBNscore should be used!")
@@ -618,11 +572,12 @@ DAGscore <- function(scorepar, incidence){
 #' \code{incidence[i,j]} equals 0 otherwise
 #' @return the log of the BGe or BDe score of the DBN
 #' @examples
-#' testscore<-scoreparameters(15, "bge", DBNdata, bgnodes=c(1,2,3), DBN=TRUE,
+#' testscore<-scoreparameters("bge", DBNdata, bgnodes=c(1,2,3), DBN=TRUE,
 #'                         dbnpar=list(slices=5, stationary=TRUE))
 #' DBNscore(testscore, DBNmat)
 #'
 #' @export
+#' @author Polina Suter, Jack Kuipers, the code partly derived from the order MCMC implementation from Kuipers J, Moffa G (2017) <doi:10.1080/01621459.2015.1133426>
 DBNscore<-function(scorepar,incidence) {
   
   if(nrow(incidence)==ncol(incidence) & ncol(incidence)==(2*scorepar$nsmall+scorepar$bgn)) {
