@@ -1,4 +1,6 @@
 #implements order MCMC on an extended search space sampling version
+#partly derived from <doi:10.1080/01621459.2015.1133426>
+
 orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,parenttable,scoretable,aliases,numparents,rowmaps,
                          plus1lists,scoresmatrices,numberofparentsvec,gamma=1,bgnodes, matsize){
   
@@ -17,8 +19,8 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
                                scoresmatrices,parenttable,numberofparentsvec,aliases) #score of a single DAG sampled from the starting order
   
   L1 <- list() # stores the adjacency matrix of a DAG sampled from the orders
-  L2 <- list() # stores its log BGe score of a DAG
-  L3 <- list() # stores the log BGe score of the entire order
+  L2 <- vector() # stores its log BGe score of a DAG
+  L3 <- vector() # stores the log BGe score of the entire order
   L4 <- list() # stores the orders as permutations
   
   zlimit<- min(floor(iterations/stepsave) + 1,1000) # number of outer iterations
@@ -29,8 +31,8 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
   length(L4) <- zlimit
   
   L1[[1]]<-currentDAG$incidence #starting DAG adjacency matrix
-  L2[[1]]<-currentDAG$logscore #starting DAG score
-  L3[[1]]<-currenttotallogscore #starting order score
+  L2[1]<-currentDAG$logscore #starting DAG score
+  L3[1]<-currenttotallogscore #starting order score
   L4[[1]]<-currentpermy[1:nsmall] #starting order
   
   
@@ -56,7 +58,7 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
                  sampledpos<-sample.int(nsmall,1)
                },
                {# if neither is chosen, we have a problem
-                 print('The move sampling has failed!')
+                 cat("The move sampling has failed!  \n")
                }) #end switch
         
         if(chosenmove<3){
@@ -86,8 +88,8 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
     currentDAG<-samplescoreplus1(matsize,mainnodes,currentorderscores,plus1lists,scoretable,scoresmatrices,
                                  parenttable,numberofparentsvec,aliases)
     L1[[z]]<-currentDAG$incidence #store adjacency matrix of a sampled DAG each 'stepsave'
-    L2[[z]]<-currentDAG$logscore #and log score of a sampled DAG
-    L3[[z]]<-currenttotallogscore #and the current order score
+    L2[z]<-currentDAG$logscore #and log score of a sampled DAG
+    L3[z]<-currenttotallogscore #and the current order score
     L4[[z]]<-currentpermy[1:nsmall] #and store current order
   }
   result<-list()
@@ -95,6 +97,7 @@ orderMCMCplus1<-function(n,nsmall,startorder,iterations,stepsave,moveprobs,paren
   result$DAGscores<-L2
   result$orderscores<-L3
   result$orders<-L4
+
   return(result)
 }
 
